import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:phone_form_field/phone_form_field.dart';

abstract class CountrySelectorNavigator {
  const CountrySelectorNavigator();
  Future<Country?> navigate(BuildContext context);

  /// for back compatibility
  static fromSelectorConfig(SelectorConfig selectorConfig) {
    if (selectorConfig is SelectorConfigBottomSheet)
      return ModalBottomSheetNavigator(height: selectorConfig.height);
    if (selectorConfig is SelectorConfigCoverSheet)
      return BottomSheetNavigator();
    if (selectorConfig is SelectorConfigDialog) return DialogNavigator();
  }
}

class DialogNavigator implements CountrySelectorNavigator {
  const DialogNavigator();

  @override
  Future<Country?> navigate(BuildContext context) {
    return showDialog<Country>(
      context: context,
      builder: (_) => Dialog(
        child: CountrySelector(
          onCountrySelected: (country) => Navigator.pop(context, country),
        ),
      ),
    );
  }
}

class BottomSheetNavigator implements CountrySelectorNavigator {
  const BottomSheetNavigator();
  @override
  Future<Country?> navigate(BuildContext context) {
    late Country selected;
    final ctrl = showBottomSheet(
      context: context,
      builder: (_) => CountrySelector(
        onCountrySelected: (country) {
          selected = country;
          Navigator.pop(context, country);
        },
      ),
    );
    return ctrl.closed.then((_) => selected);
  }
}

class ModalBottomSheetNavigator implements CountrySelectorNavigator {
  final double? height;

  const ModalBottomSheetNavigator({this.height});

  @override
  Future<Country?> navigate(BuildContext context) {
    return showModalBottomSheet<Country>(
      context: context,
      builder: (_) => SizedBox(
        height: height ?? MediaQuery.of(context).size.height - 90,
        child: CountrySelector(
          onCountrySelected: (country) => Navigator.pop(context, country),
        ),
      ),
      isScrollControlled: true,
    );
  }
}
